@@ -48,6 +48,7 @@
 #include <config.h>
 
 #include <ctype.h>
+#include <limits.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -84,9 +85,12 @@ lengthen (char **start, char **track, size_t *size, size_t add)
   return EXIT_SUCCESS;
 }
 
+#define MAX_MACRO_NESTING_DEPTH 1000
+
 void
 domacro (int argc, char *argv[])
 {
+  static int nesting_depth = 0;
   int i, j, count = 2, loopflg = 0, allocflg = 0;
   char *cp1, *cp2;
   char *line2;		/* Saved original of `line'.  */
@@ -113,6 +117,12 @@ domacro (int argc, char *argv[])
       code = -1;
       return;
     }
+  if (nesting_depth < 0)
+    {
+      printf ("?Corrupted macro execution state.\n");
+      code = -1;
+      return;
+    }
 
   line2 = line;
   line2len = linelen;
@@ -141,6 +151,12 @@ domacro (int argc, char *argv[])
   line = cp2;
   *line = '\0';
 
+  if (++nesting_depth > MAX_MACRO_NESTING_DEPTH)
+    {
+      printf ("?Maximum macro nesting depth reached, aborting macro.\n");
+      goto end_exec;
+    }
+
   do
     {
       cp1 = macros[i].mac_start;
@@ -178,9 +194,12 @@ domacro (int argc, char *argv[])
 		      /* Argument expansion.  */
 		      j = 0;
 		      while (isdigit (*++cp1))
-			j = 10 * j + *cp1 - '0';
+			{
+			  if (j <= (INT_MAX - 9) / 10)
+			    j = 10 * j + *cp1 - '0';
+			}
 		      cp1--;
-		      if (argc - 2 >= j)
+		      if (argc - 2 >= j && j >= 0)
 			{
 			  if (lengthen (&line, &cp2, &linelen,
 					strlen (argv[j + 1]) + 2))
@@ -227,7 +246,10 @@ domacro (int argc, char *argv[])
 	  *cp2 = '\0';
 	  makeargv ();
 	  if (margv[0] == NULL)
-	    return;
+	    {
+	      nesting_depth--;
+	      return;
+	    }
 	  c = getcmd (margv[0]);
 
 	  if (c == (struct cmd *) -1)
@@ -262,8 +284,23 @@ domacro (int argc, char *argv[])
 	      /* The arguments set at the time of invoking
 	       * the macro must be recovered, to be used
 	       * in parsing next line of macro definition.
+	       *
+	       * Executing a macro line can change "line"
+	       * to no longer provide sufficient space for
+	       * the saved line2 contents.
 	       */
-	      strcpy (line, line2);	/* Known to fit.  */
+	      if (strlen(line2) >= linelen)
+		{
+		  char *tmp = realloc (line, strlen(line2) + 1);
+		  if (tmp == NULL)
+		    {
+		      allocflg = 1;
+		      goto end_exec;
+		    }
+		  line = tmp;
+		  linelen = strlen(line2) + 1;
+		}
+	      strcpy (line, line2);
 	      makeargv ();		/* Get the arguments.  */
 	      argc = margc;
 	      argv = margv;
@@ -283,4 +320,5 @@ end_exec:
   free (line);
   line = line2;
   linelen = line2len;
+  nesting_depth--;
 }
