@@ -1,7 +1,5 @@
 /*
-  Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008,
-  2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019,
-  2020, 2021 Free Software Foundation, Inc.
+  Copyright (C) 2000-2022 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -39,7 +37,7 @@
 #endif
 
 #include <libinetutils.h>
-#include "unused-parameter.h"
+#include "attribute.h"
 
 int usefamily = AF_UNSPEC;	/* Address family for daemon.  */
 
@@ -97,7 +95,7 @@ check_host (struct sockaddr *sa, socklen_t len)
 #endif /* WITH_WRAP */
 
 static void
-reapchild (int signo _GL_UNUSED_PARAMETER)
+reapchild (int signo MAYBE_UNUSED)
 {
   int save_errno = errno;
 
