@@ -1,7 +1,5 @@
 /* options.c -- process the command line options
-  Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009,
-  2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021
-  Free Software Foundation, Inc.
+  Copyright (C) 2001-2022 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -39,7 +37,7 @@
 #include <sys/socket.h>
 #include <net/if.h>
 
-#include <unused-parameter.h>
+#include <attribute.h>
 
 #include "ifconfig.h"
 
@@ -380,7 +378,7 @@ void parse_opt_set_af (struct ifconfig *ifp, char *af)
 }
 
 void
-parse_opt_set_flag (struct ifconfig *ifp _GL_UNUSED_PARAMETER,
+parse_opt_set_flag (struct ifconfig *ifp MAYBE_UNUSED,
 		    int flag, int rev)
 {
   if (ifp)
@@ -549,8 +547,29 @@ parse_opt (int key, char *arg, struct argp_state *state)
       break;
 
     case 'A':		/* Interface address.  */
-      parse_opt_set_address (ifp, arg);
-      break;
+      {
+	char *netlen = strchr (arg, '/');
+
+	if (netlen)
+	  {
+	    char *end, *str;
+	    unsigned n;
+	    struct in_addr addr;
+
+	    *netlen++ = 0;
+
+	    n = strtol (netlen, &end, 10);
+	    if (end == netlen)
+	      error (EXIT_FAILURE, 0, "Wrong netmask length %s", netlen);
+
+	    addr.s_addr = htonl (INADDR_BROADCAST << (32-n));
+	    str = strdup (inet_ntoa (addr));
+	    parse_opt_set_netmask (ifp, str);
+	  }
+
+	parse_opt_set_address (ifp, arg);
+	break;
+      }
 
     case 'm':		/* Interface netmask.  */
       parse_opt_set_netmask (ifp, arg);
@@ -614,7 +633,7 @@ parse_opt (int key, char *arg, struct argp_state *state)
 
 static char *
 default_help_filter (int key, const char *text,
-		     void *input _GL_UNUSED_PARAMETER)
+		     void *input MAYBE_UNUSED)
 {
   char *s;
 
@@ -690,15 +709,15 @@ parse_cmdline (int argc, char *argv[])
 		   "can't get memory for interface configuration");
 	  ifp = &ifs[nifs - 1];
 	  *ifp = ifconfig_initializer;
-	  ifp->name = ifnxp->if_name;
+	  ifp->name = strdup (ifnxp->if_name);
+	  if (!ifs)
+	    error (EXIT_FAILURE, errno,
+		   "can't get memory for interface configuration name");
 	  ifp->valid = IF_VALID_FORMAT;
 	  ifp->format = default_format;
 	  ifnxp++;
 	}
-      /* XXX: We never do if_freenameindex (ifnx), because we are
-	 keeping the names for later instead using strdup
-	 (if->if_name) here.  */
-
+      if_freenameindex (ifnx);
       qsort (ifs, nifs, sizeof (ifs[0]), cmp_if_name);
     }
 }
