@@ -1,7 +1,5 @@
 /*
-  Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009,
-  2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021
-  Free Software Foundation, Inc.
+  Copyright (C) 2001-2022 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -66,6 +64,7 @@ extern const char *system_default_format;
 # undef SYSTEM_FORMAT_HANDLER
 
 
+int system_preconfigure (int sfd, struct ifreq *ifr);
 int system_configure (int sfd, struct ifreq *ifr,
 		      struct system_ifconfig *__ifs);
 
