@@ -551,7 +551,7 @@ system_fh_hwaddr_query (format_data_t form, int argc, char *argv[])
 
 void
 system_fh_hwaddr (format_data_t form, int argc MAYBE_UNUSED,
-		  char *argv[] MAYBE_UNUSED)
+		  MAYBE_UNUSED char *argv[])
 {
 #ifdef SIOCGIFHWADDR
   if (ioctl (form->sfd, SIOCGIFHWADDR, form->ifr) < 0)
@@ -588,7 +588,7 @@ system_fh_hwtype_query (format_data_t form, int argc, char *argv[])
 
 void
 system_fh_hwtype (format_data_t form, int argc MAYBE_UNUSED,
-		  char *argv[] MAYBE_UNUSED)
+		  MAYBE_UNUSED char *argv[])
 {
 #ifdef SIOCGIFHWADDR
   if (ioctl (form->sfd, SIOCGIFHWADDR, form->ifr) < 0)
@@ -894,6 +894,13 @@ system_parse_opt_rest (struct ifconfig **ifp, int argc, char *argv[])
 }
 
 
+int
+system_preconfigure (int sfd MAYBE_UNUSED,
+		     struct ifreq *ifr MAYBE_UNUSED)
+{
+  return 0;
+}
+
 int
 system_configure (int sfd, struct ifreq *ifr, struct system_ifconfig *ifs)
 {
