@@ -1,6 +1,6 @@
 /* inttostr.h -- convert integers to printable strings
 
-   Copyright (C) 2001-2006, 2009-2021 Free Software Foundation, Inc.
+   Copyright (C) 2001-2006, 2009-2022 Free Software Foundation, Inc.
 
    This file is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as
@@ -22,8 +22,8 @@
 
 #include "intprops.h"
 
-char *imaxtostr (intmax_t, char *) _GL_ATTRIBUTE_NODISCARD;
-char *inttostr (int, char *) _GL_ATTRIBUTE_NODISCARD;
-char *offtostr (off_t, char *) _GL_ATTRIBUTE_NODISCARD;
-char *uinttostr (unsigned int, char *) _GL_ATTRIBUTE_NODISCARD;
-char *umaxtostr (uintmax_t, char *) _GL_ATTRIBUTE_NODISCARD;
+_GL_ATTRIBUTE_NODISCARD char *imaxtostr (intmax_t, char *);
+_GL_ATTRIBUTE_NODISCARD char *inttostr (int, char *);
+_GL_ATTRIBUTE_NODISCARD char *offtostr (off_t, char *);
+_GL_ATTRIBUTE_NODISCARD char *uinttostr (unsigned int, char *);
+_GL_ATTRIBUTE_NODISCARD char *umaxtostr (uintmax_t, char *);
