@@ -1,7 +1,5 @@
 /*
-  Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008,
-  2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019,
-  2020, 2021 Free Software Foundation, Inc.
+  Copyright (C) 2000-2022 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -56,7 +54,7 @@
 #include <sys/stat.h>
 
 #include <errno.h>
-#include "fts.h"
+#include <fts_.h>
 #include <grp.h>
 #include <pwd.h>
 #include <stdio.h>
