@@ -57,9 +57,9 @@
  * the length of *s1 is returned.
  */
 int
-isprefix (register char *s1, register char *s2)
+isprefix (register const char *s1, register const char *s2)
 {
-  char *os1;
+  const char *os1;
   register char c1, c2;
 
   if (*s1 == '\0')
@@ -82,7 +82,7 @@ static char *ambiguous;		/* special return value for command routines */
 /* char	*name; name to match */
 /* char	**table; name entry in table */
 char **
-genget (char *name, char **table, int stlen)
+genget (const char *name, char **table, int stlen)
 {
   register char **c, **found;
   register int n;
@@ -108,7 +108,7 @@ genget (char *name, char **table, int stlen)
  * Function call version of Ambiguous()
  */
 int
-Ambiguous (char *s)
+Ambiguous (void *s)
 {
-  return ((char **) s == &ambiguous);
+  return (s == &ambiguous);
 }
