@@ -1,6 +1,5 @@
 /*
-  Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
-  2018, 2019, 2020, 2021 Free Software Foundation, Inc.
+  Copyright (C) 2009-2022 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -41,7 +40,7 @@
 #include <error.h>
 #include <xalloc.h>
 #include <inttostr.h>
-#include <unused-parameter.h>
+#include <attribute.h>
 
 #define SYSLOG_NAMES
 #include <syslog.h>
@@ -327,7 +326,7 @@ send_to_syslog (const char *msg)
       ioptr->iov_base = (char*) msg;
       ioptr->iov_len = msglen;
 
-      if (msg[msglen - 1] != '\n')
+      if (msglen > 0 && msg[msglen - 1] != '\n')
 	{
 	  /* provide a newline */
 	  ioptr++;
@@ -374,7 +373,7 @@ static struct argp_option argp_options[] = {
 };
 
 static error_t
-parse_opt (int key, char *arg, struct argp_state *state _GL_UNUSED_PARAMETER)
+parse_opt (int key, char *arg, struct argp_state *state MAYBE_UNUSED)
 {
   switch (key)
     {
