@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1993-2020 Free Software Foundation, Inc.
+  Copyright (C) 1993-2022 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -109,7 +109,7 @@
 #include <progname.h>
 #include <argp.h>
 #include <error.h>
-#include <unused-parameter.h>
+#include <attribute.h>
 #include "libinetutils.h"
 
 void die (int code, const char *fmt, ...);
@@ -134,8 +134,8 @@ static struct argp_option options[] = {
 };
 
 static error_t
-parse_opt (int key, char *arg _GL_UNUSED_PARAMETER,
-	   struct argp_state *state _GL_UNUSED_PARAMETER)
+parse_opt (int key, char *arg MAYBE_UNUSED,
+	   struct argp_state *state MAYBE_UNUSED)
 {
   switch (key)
     {
@@ -556,8 +556,9 @@ doit (int f, struct sockaddr *fromp, socklen_t fromlen)
 
 #ifdef HAVE_SETLOGIN
       /* Not sufficient to call setpgid() on BSD systems.  */
-      if (setsid () < 0)
-	syslog (LOG_ERR, "setsid() failed: %m");
+      if (getsid ((pid_t) 0) != getpid ())
+	if (setsid () < 0)
+	  syslog (LOG_ERR, "setsid() failed: %m");
 #elif defined HAVE_SETPGID /* !HAVE_SETLOGIN */
       setpgid (0, getpid ());
 #endif
@@ -726,7 +727,7 @@ getstr (const char *err)
 static int
 rexec_conv (int num, const struct pam_message **pam_msg,
 	    struct pam_response **pam_resp,
-	    void *data _GL_UNUSED_PARAMETER)
+	    void *data MAYBE_UNUSED)
 {
   struct pam_response *resp;
 
