@@ -1,8 +1,5 @@
 /*
-  Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
-  2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014,
-  2015, 2016, 2017, 2018, 2019, 2020, 2021 Free Software Foundation,
-  Inc.
+  Copyright (C) 1995-2022 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -83,7 +80,7 @@
 #endif
 
 #include <argp.h>
-#include <unused-parameter.h>
+#include <attribute.h>
 
 #include <libinetutils.h>
 
@@ -125,7 +122,10 @@ static int fromatty;
 char mode[32];
 char line[200];
 int margc;
-char *margv[20];
+
+#define TFTP_MAX_ARGS 20
+
+char *margv[TFTP_MAX_ARGS];
 char *prompt = "tftp";
 jmp_buf toplevel;
 void intr (int signo);
@@ -516,13 +516,13 @@ modecmd (int argc, char *argv[])
 }
 
 void
-setbinary (int argc _GL_UNUSED_PARAMETER, char *argv[] _GL_UNUSED_PARAMETER)
+setbinary (int argc MAYBE_UNUSED, MAYBE_UNUSED char *argv[])
 {
   settftpmode ("octet");
 }
 
 void
-setascii (int argc _GL_UNUSED_PARAMETER, char *argv[] _GL_UNUSED_PARAMETER)
+setascii (int argc MAYBE_UNUSED, MAYBE_UNUSED char *argv[])
 {
   settftpmode ("netascii");
 }
@@ -792,7 +792,7 @@ settimeout (int argc, char *argv[])
 }
 
 void
-status (int argc _GL_UNUSED_PARAMETER, char *argv[] _GL_UNUSED_PARAMETER)
+status (int argc MAYBE_UNUSED, MAYBE_UNUSED char *argv[])
 {
   if (connected)
     printf ("Connected to %s.\n", hostname);
@@ -805,7 +805,7 @@ status (int argc _GL_UNUSED_PARAMETER, char *argv[] _GL_UNUSED_PARAMETER)
 }
 
 void
-intr (int signo _GL_UNUSED_PARAMETER)
+intr (int signo MAYBE_UNUSED)
 {
   signal (SIGALRM, SIG_IGN);
   alarm (0);
@@ -917,6 +917,11 @@ makeargv (void)
 	cp++;
       if (*cp == '\0')
 	break;
+      if (margc + 1 >= TFTP_MAX_ARGS)
+	{
+	  fprintf (stderr, "Ignoring excess arguments.\n");
+	  break;
+	}
       *argp++ = cp;
       margc += 1;
       while (*cp != '\0' && !isspace (*cp))
@@ -929,7 +934,7 @@ makeargv (void)
 }
 
 void
-quit (int argc _GL_UNUSED_PARAMETER, char *argv[] _GL_UNUSED_PARAMETER)
+quit (int argc MAYBE_UNUSED, MAYBE_UNUSED char *argv[])
 {
   exit (EXIT_SUCCESS);
 }
@@ -966,14 +971,14 @@ help (int argc, char *argv[])
 }
 
 void
-settrace (int argc _GL_UNUSED_PARAMETER, char *argv[] _GL_UNUSED_PARAMETER)
+settrace (int argc MAYBE_UNUSED, MAYBE_UNUSED char *argv[])
 {
   trace = !trace;
   printf ("Packet tracing %s.\n", trace ? "on" : "off");
 }
 
 void
-setverbose (int argc _GL_UNUSED_PARAMETER, char *argv[] _GL_UNUSED_PARAMETER)
+setverbose (int argc MAYBE_UNUSED, MAYBE_UNUSED char *argv[])
 {
   verbose = !verbose;
   printf ("Verbose mode %s.\n", verbose ? "on" : "off");
@@ -1378,7 +1383,7 @@ printstats (const char *direction, unsigned long amount)
 }
 
 static void
-timer (int sig _GL_UNUSED_PARAMETER)
+timer (int sig MAYBE_UNUSED)
 {
   timeout += rexmtval;
   if (timeout >= maxtimeout)
