@@ -1,8 +1,5 @@
 /*
-  Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
-  2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014,
-  2015, 2016, 2017, 2018, 2019, 2020, 2021 Free Software Foundation,
-  Inc.
+  Copyright (C) 1995-2022 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -85,7 +82,7 @@
 
 #include "tftpsubs.h"
 
-#include <unused-parameter.h>
+#include <attribute.h>
 #include <xalloc.h>
 #include <argp.h>
 #include <progname.h>
@@ -165,7 +162,7 @@ static struct argp_option options[] = {
 
 static error_t
 parse_opt (int key, char *arg,
-	   struct argp_state *state _GL_UNUSED_PARAMETER)
+	   struct argp_state *state MAYBE_UNUSED)
 {
   switch (key)
     {
@@ -636,7 +633,7 @@ int timeout;
 sigjmp_buf timeoutbuf;
 
 void
-timer (int sig _GL_UNUSED_PARAMETER)
+timer (int sig MAYBE_UNUSED)
 {
 
   timeout += rexmtval;
@@ -716,7 +713,7 @@ abort:
 }
 
 void
-justquit (int sig _GL_UNUSED_PARAMETER)
+justquit (int sig MAYBE_UNUSED)
 {
   exit (EXIT_SUCCESS);
 }
