@@ -1,8 +1,5 @@
 /*
-  Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
-  2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012,
-  2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021 Free Software
-  Foundation, Inc.
+  Copyright (C) 1993-2022 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -628,7 +625,7 @@ clientstat (register int code, register int parm1, register int parm2)
 	/*
 	 * Change terminal speed as requested by client.
 	 * We set the receive speed first, so that if we can't
-	 * store seperate receive and transmit speeds, the transmit
+	 * store separate receive and transmit speeds, the transmit
 	 * speed will take precedence.
 	 */
 	tty_rspeed (parm2);
