@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# Copyright (C) 2011-2020 Free Software Foundation, Inc.
+# Copyright (C) 2011-2022 Free Software Foundation, Inc.
 #
 # This file is part of GNU Inetutils.
 #
@@ -98,6 +98,43 @@ if test ! -x $ADDRPEEK; then
     exit 77
 fi
 
+if test "$TEST_IPV4" = "no" && test "$TEST_IPV6" = "no"; then
+    echo >&2 "Inet socket testing is disabled.  Skipping test."
+    exit 77
+fi
+
+# Check regression of crash reported here:
+# https://lists.gnu.org/archive/html/bug-inetutils/2022-02/msg00014.html
+echo 'help z ! ? z ! ? z ! ? z ! ? z ! ? z ! ? z !' | $TELNET > /dev/null
+if test $? -ne 0; then
+    echo "Regression of telnet crash bug." >&2
+    exit 1
+fi
+
+# Check regression of crash reported here:
+# https://lists.gnu.org/archive/html/bug-inetutils/2022-02/msg00009.html
+echo 'help help' | $TELNET > /dev/null
+if test $? -ne 0; then
+    echo "Regression of telnet second crash bug." >&2
+    exit 1
+fi
+
+# Check regression of crash reported here:
+# https://lists.gnu.org/archive/html/bug-inetutils/2022-02/msg00007.html
+echo "unset ' '" | $TELNET > /dev/null
+if test $? -ne 0; then
+    echo "Regression of telnet third crash bug." >&2
+    exit 1
+fi
+
+# Check regression of crash reported here:
+# https://lists.gnu.org/archive/html/bug-inetutils/2022-02/msg00010.html
+echo "set ' ' foo" | $TELNET > /dev/null
+if test $? -ne 0; then
+    echo "Regression of telnet fourth crash bug." >&2
+    exit 1
+fi
+
 # Portability fix for SVR4
 PWD="${PWD:-`pwd`}"
 
@@ -132,14 +169,20 @@ trap posttesting EXIT HUP INT QUIT TERM
 
 PORT=`expr 4973 + ${RANDOM:-$$} % 973`
 
-cat > "$INETD_CONF" <<-EOF ||
-	$TARGET:$PORT stream tcp4 nowait $USER $ADDRPEEK addrpeek addr
-EOF
+# Create an empty configuration file for inetd.
+: > "$INETD_CONF" 2>/dev/null ||
     {
 	echo 'Could not create configuration file for Inetd.  Aborting.' >&2
 	exit 1
     }
 
+# This target is used for plain IPv4 and for IPv4-mapped addressing.
+if test "$TEST_IPV4" != "no"; then
+    cat >> "$INETD_CONF" <<-EOF
+	$TARGET:$PORT stream tcp4 nowait $USER $ADDRPEEK addrpeek addr
+EOF
+fi
+
 if test "$TEST_IPV6" != "no"; then
     cat >> "$INETD_CONF" <<-EOF
 	$TARGET6:$PORT stream tcp6 nowait $USER $ADDRPEEK addrpeek addr
@@ -180,14 +223,14 @@ telnet_opts="--no-rc --no-escape --no-login"
 
 errno=0
 
-if test -n "$TARGET"; then
+if test "$TEST_IPV4" != "no" && test -n "$TARGET"; then
     output=`$TELNET $telnet_opts $TARGET $PORT 2>/dev/null`
     echo "$output" | eval "$GREP 'Your address is $TARGET.' $display"
     if test $? -ne 0; then
 	errno=1
 	echo "Failed at '$TARGET'." >&2
     fi
-fi
+fi # TEST_IPV4 && TARGET
 
 if test "$TEST_IPV6" != "no" && test -n "$TARGET6"; then
     output=`$TELNET $telnet_opts $TARGET6 $PORT 2>/dev/null`
@@ -196,14 +239,15 @@ if test "$TEST_IPV6" != "no" && test -n "$TARGET6"; then
 	errno=1
 	echo "Failed at '$TARGET6'." >&2
     fi
-fi
+fi # TEST_IPV6 && TARGET6
 
-if test "$TEST_IPV6" != "no" && test -n "$TARGET46"; then
+if test "$TEST_IPV4" != "no" && test "$TEST_IPV6" != "no" \
+   && test -n "$TARGET46"; then
     output=`$TELNET $telnet_opts $TARGET46 $PORT 2>/dev/null`
     echo "$output" | eval "$GREP 'Your address is .*$TARGET.' $display"
     if test $? -ne 0; then
 	echo "Informational: Unsuccessful with mapped address '$TARGET46'." >&2
     fi
-fi
+fi # TEST_IPV4 && TEST_IPV6 && TARGET46
 
 exit $errno
