@@ -28,6 +28,7 @@
     ".am",	"\001http://www.amnic.net/cgi/engine/db/whois.html",
     ".aq",	"\003",
     ".ar",	"\001http://www.nic.ar/consultas/consdom.htm",
+    ".art",	"whois.nic.art",
     ".as",	"whois.nic.as",
     ".at",	"whois.ripe.net",
     ".net.au",	"whois.connect.com.au",
@@ -101,7 +102,7 @@
     ".ie",	"whois.domainregistry.ie",
     ".il",	"whois.isoc.org.il",
     ".im",	"whois.nic.im",
-    ".in",	"whois.inregistry.net",
+    ".in",	"whois.registry.in",
     ".io",	"whois.nic.io",
     ".ir",	"whois.nic.ir",
     ".is",	"whois.isnic.is",
@@ -153,6 +154,7 @@
     ".np",	"\001http://202.52.255.47/search.htm",
     ".nu",	"whois.nic.nu",
     ".nz",	"whois.srs.net.nz",
+    ".org",	"whois.pir.org",
     ".pa",	"\001http://www.nic.pa",
     ".pe",	"kero.yachay.pe",
     ".pg",	"\003",
