@@ -1,7 +1,5 @@
 /*
-  Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-  2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017,
-  2018, 2019, 2020, 2021 Free Software Foundation, Inc.
+  Copyright (C) 1998-2022 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -41,7 +39,7 @@
 #define obstack_chunk_free free
 #include <obstack.h>
 #include <error.h>
-#include <unused-parameter.h>
+#include <attribute.h>
 #include <libinetutils.h>
 
 /* Application-specific */
@@ -103,7 +101,7 @@ static struct argp_option ripe_argp_options[] = {
 
 static error_t
 ripe_argp_parser (int key, char *arg,
-		  struct argp_state *state _GL_UNUSED_PARAMETER)
+		  struct argp_state *state MAYBE_UNUSED)
 {
   if (key > 0 && (unsigned) key < 128)
     {
@@ -142,7 +140,7 @@ static struct argp_option gwhois_argp_options[] = {
 
 static error_t
 gwhois_argp_parser (int key, char *arg,
-		    struct argp_state *state _GL_UNUSED_PARAMETER)
+		    struct argp_state *state MAYBE_UNUSED)
 {
   char *p, *q;
 
